pub trait Identifier: ToString { }Expand description
An Identifier is a type that can be used as an identifier
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Identifier: ToString { }An Identifier is a type that can be used as an identifier
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".